Swift client generation.
Generates caller protocol and client implementation for making RPC calls.
Functions
- generate_
client - Generate complete client code (caller protocol + client implementation).
Swift client generation.
Generates caller protocol and client implementation for making RPC calls.