Module encode

Module encode 

Swift encoding expression generation.

Generates Swift code that encodes Rust types into byte arrays.

Functions

generate_encode_closure
Generate a Swift encode closure for use with encodeVec, encodeOption, etc.
generate_encode_expr
Generate a Swift encode expression for a given shape and value.
swift_encode_fn
Get the Swift encode function name for a scalar type.