Swift server/handler generation.
Generates handler protocol and dispatcher for routing incoming calls.
Functions
- generate_
server - Generate complete server code (handler protocol + dispatchers).
Swift server/handler generation.
Generates handler protocol and dispatcher for routing incoming calls.