Module encode

Module encode 

TypeScript encoding expression generation.

Generates TypeScript code that encodes Rust types into byte arrays.

Functions

generate_encode_expr
Generate a TypeScript expression that encodes a value of the given type. expr is the JavaScript expression to encode.
generate_encode_fn_inline
Generate an inline encode function for a type.