Swift encoding expression generation.
Generates Swift code that encodes Rust types into byte arrays.
Functions
- generate_
encode_ closure - Generate a Swift encode closure for use with encodeVec, encodeOption, etc.
- generate_
encode_ expr - Generate a Swift encode expression for a given shape and value.
- swift_
encode_ fn - Get the Swift encode function name for a scalar type.