TypeScript encoding expression generation.
Generates TypeScript code that encodes Rust types into byte arrays.
Functions
- generate_
encode_ expr - Generate a TypeScript expression that encodes a value of the given type.
expris the JavaScript expression to encode. - generate_
encode_ fn_ inline - Generate an inline encode function for a type.